@@ -11,7 +11,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::NextVersion;
 {
-  $Dist::Zilla::Plugin::Git::NextVersion::VERSION = '2.012';
+  $Dist::Zilla::Plugin::Git::NextVersion::VERSION = '2.016';
 }
 # ABSTRACT: provide a version number by bumping the last git release tag
 
@@ -98,6 +98,7 @@ sub _last_version {
         /^\s*\((.+)\)/ or next;
         push @tags, split /,\s*/, $1;
       } # end for lines from git log
+      s/^tag:\s+// for @tags;   # Git 1.8.3 says "tag: X" instead of "X"
       my $versions = _versions_from_tags($self->version_regexp, \@tags);
       if ($self->logger->get_debug) {
         $self->log_debug("Found version $_ on branch") for @$versions;
@@ -182,7 +183,7 @@ Dist::Zilla::Plugin::Git::NextVersion - provide a version number by bumping the
 
 =head1 VERSION
 
-version 2.012
+version 2.016
 
 =head1 SYNOPSIS
 
@@ -232,7 +233,7 @@ C<version_regexp> - regular expression that matches a tag containing
 a version.  It must capture the version into $1.  Defaults to ^v(.+)$
 which matches the default C<tag_format> from the
 L<Git::Tag|Dist::Zilla::Plugin::Git::Tag> plugin.
-If you change C<tag_format>, you B<must> set a corresponsing C<version_regexp>.
+If you change C<tag_format>, you B<must> set a corresponding C<version_regexp>.
 
 =back
 
